# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]
## [0.2] - 2021-01-29
### Added
- `_playsound_async` function
- `play_sound` function
- `inhale.wav`
- `exhale.wav`
- `sustain.wav`
- `retain.wav`
- `get_sound_path` function
- `program_description_print` function
- `time_convert` function
### Changed
- Menu optimized
- Test system modified
- `get_program_dict` function renamed to `get_program_data`
- `program_dict` parameter renamed to `program_data`
- `input_dict` parameter renamed to `input_data`
- `README.md` updated
## [0.1] - 2020-10-30
### Added
- Clear Mind program
- Relax program
- Calming program
- Power program
- Anti-Stress program
- Anti-Appetite program 
- Cigarette Replace program

[Unreleased]: https://github.com/sepandhaghighi/nafas/compare/v0.2...dev
[0.2]: https://github.com/sepandhaghighi/nafas/compare/v0.1...v0.2
[0.1]: https://github.com/sepandhaghighi/nafas/compare/c58087a...v0.1



